@@ -22,9 +22,6 @@ from meutils.pipe import *
 from meutils.str_utils import json_loads
 
 
-# app_ = FastAPI(title='AppZoo')  # todo: 全局变量
-
-
 class App(object):
     """
     from appzoo import App
@@ -36,12 +33,11 @@ class App(object):
         app.run(app.app_from(__file__), port=9955, debug=True)
     """
 
-    def __init__(self, verbose=True):
+    def __init__(self, **kwargs):
         self.app = FastAPI(title='AppZoo')
-        # self.app = app_
 
         # 增加配置项，方便热更新
-        self.config = {}  # self.config===body_json
+        self.config = {}
         self.add_route_plus(self.app_config, methods=["GET", "POST"])
 
         # 原生接口
@@ -102,6 +98,7 @@ class App(object):
         :return:
         """
         assert isinstance(func, Callable)
+
         if isinstance(methods, str):
             methods = [methods]
 
@@ -116,15 +113,11 @@ class App(object):
     def add_route_uploadfiles(self, path='/xxx', func=lambda x='demo': x, **kwargs):
         """
         def read_func(**kwargs):
-        logger.info(kwargs)
-        return pd.read_csv(kwargs['files'][0], names=['word']).to_dict('r')
+            logger.info(kwargs)
+            return pd.read_csv(kwargs['files'][0], names=['word']).to_dict('r')
 
         app.add_route_uploadfiles('/upload', read_func)
 
-        :param path:
-        :param func:
-        :param kwargs:
-        :return:
         """
 
         handler = self._handler4files(func, **kwargs)
@@ -187,20 +180,14 @@ class App(object):
 
         return handler
 
-    def _handler4files(self, func, result_key='data', **kwargs):
-        """
-
-        :param func:
-        :param result_key:
-        :return:
-        """
+    def _handler4files(self, func, **kwargs):
 
         async def handler(request: Request, files: List[UploadFile] = File(...)):
             input = request.query_params._dict
 
             input['files'] = [BytesIO(await file.read()) for file in files]
 
-            return self._try_func(input, func, result_key, **kwargs)
+            return self._try_func_plus(input, func, **kwargs)
 
         return handler
 
@@ -264,14 +251,8 @@ class App(object):
 
             logger.error(output['msg'])
 
-        # finally:
-        #     output.update(kwargs)
-
         return output
 
-    def app_file_name(self, file=__file__):
-        return Path(file).stem
-
     def app_from(self, file=__file__, app='app_'):
         return f"{Path(file).stem}:{app}"
 
@@ -283,6 +264,10 @@ class App(object):
 
         return self.config
 
+    def set_data(self, kwargs: dict):  # redis 单机绑定到内存也行
+        key = kwargs.pop('key')
+        data = kwargs.pop('key')
+
 
 if __name__ == '__main__':
     import uvicorn
