@@ -22,4 +22,4 @@ app = app_.app
 
 if __name__ == '__main__':
     # app.run(port=1234)
-    app_.run(app_.app_file_name(__file__), port=4321, debug=True, reload=True)
+    app_.run(app_.app_file_name(__file__), port=4321, debug=True)
